@@ -20,13 +20,15 @@
 #include "config.h"
 #include <parted/parted.h>
 
-#include <libintl.h>
 #if ENABLE_NLS
+#  include <libintl.h>
 #  define _(String) dgettext (PACKAGE, String)
 #else
 #  define _(String) (String)
 #endif /* ENABLE_NLS */
 
+#ifdef DEBUG
+
 int
 ped_assert (int cond, char* cond_text, char* file, int line, char* function)
 {
@@ -44,3 +46,5 @@ ped_assert (int cond, char* cond_text, char* file, int line, char* function)
 	return opt == PED_EXCEPTION_IGNORE;
 }
 
+#endif /* DEBUG */
+
