@@ -17,10 +17,10 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-static const char _ext2_block_relocator_c[] = "$Id: ext2_block_relocator.c,v 1.5 1999/10/02 20:56:47 aclausen Exp $";
-
 #include "config.h"
 
+#ifndef DISCOVER_ONLY
+
 #include <stdio.h>
 #include <stdlib.h>
 #include "ext2.h"
@@ -175,7 +175,7 @@ static int doindblock(struct ext2_fs *fs,
 {
 	struct ext2_buffer_head *bh;
 	int			 i;
-	__u32			*uptr;
+	uint32_t		*uptr;
 
 	if (!doblock(fs, state, blk, refblock, refoffset, 1))
 		return 0;
@@ -183,7 +183,7 @@ static int doindblock(struct ext2_fs *fs,
 	bh = ext2_bread(fs, blk);
 	if (!bh)
 		return 0;
-	uptr = (__u32 *)bh->data;
+	uptr = (uint32_t *)bh->data;
 
 	for (i=0;i<(fs->blocksize >> 2);i++)
 		if (uptr[i])
@@ -205,7 +205,7 @@ static int dodindblock(struct ext2_fs *fs,
 {
 	struct ext2_buffer_head *bh;
 	int			 i;
-	__u32			*uptr;
+	uint32_t		*uptr;
 
 	if (!doblock(fs, state, blk, refblock, refoffset, 2))
 		return 0;
@@ -213,7 +213,7 @@ static int dodindblock(struct ext2_fs *fs,
 	bh = ext2_bread(fs, blk);
 	if (!bh)
 		return 0;
-	uptr = (__u32 *)bh->data;
+	uptr = (uint32_t *)bh->data;
 
 	for (i=0;i<(fs->blocksize >> 2);i++)
 		if (uptr[i])
@@ -235,7 +235,7 @@ static int dotindblock(struct ext2_fs *fs,
 {
 	struct ext2_buffer_head *bh;
 	int			 i;
-	__u32			*uptr;
+	uint32_t		*uptr;
 
 	if (!doblock(fs, state, blk, refblock, refoffset, 3))
 		return 0;
@@ -243,7 +243,7 @@ static int dotindblock(struct ext2_fs *fs,
 	bh = ext2_bread(fs, blk);
 	if (!bh)
 		return 0;
-	uptr = (__u32 *)bh->data;
+	uptr = (uint32_t *)bh->data;
 
 	for (i=0;i<(fs->blocksize >> 2);i++)
 		if (uptr[i])
@@ -497,7 +497,7 @@ static int ext2_block_relocator_ref(struct ext2_fs *fs, struct ext2_block_reloca
 
 	if (fs->opt_debug)
 	{
-		if (PED_LE32_TO_CPU(*((__u32 *)(bh->data + block->refoffset)))
+		if (PED_LE32_TO_CPU(*((uint32_t *)(bh->data + block->refoffset)))
 				!= block->num) {
 			fprintf(stderr,
 				"block %i ref error! (->%i {%i, %i})\n",
@@ -515,7 +515,7 @@ static int ext2_block_relocator_ref(struct ext2_fs *fs, struct ext2_block_reloca
 		}
 	}
 
-	*((__u32 *)(bh->data + block->refoffset))
+	*((uint32_t *)(bh->data + block->refoffset))
 		= PED_LE32_TO_CPU(block->dest);
 	bh->dirty = 1;
 	ext2_brelse(bh, 0);
@@ -860,3 +860,5 @@ int ext2_block_relocate(struct ext2_fs *fs, blk_t newsize)
 
 	return ext2_block_relocate_grow(fs, &state, newsize);
 }
+
+#endif /* !DISCOVER_ONLY */
